@@ -1617,7 +1617,7 @@ class Insight_Definition:
                 insight_definition.delete()
             except Exception as e:
                 logging.info("{} card not found... creating new one".format(card_slug))
-                logging.info("{}".format(e.__str__()))
+                #logging.info("{}".format(e.__str__()))
 
 
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/clone"
